@@ -1,15 +1,22 @@
 //
 //
-// C++ Implementation: $MODULE$
-//
-// Description: 
+// Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2005
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2005 Liviu Lalescu <http://lalescu.ro/liviu/>
 //
-// Copyright: See COPYING file that comes with this distribution
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 //
 //
+
 #include "building.h"
 #include "rules.h"
 
@@ -26,16 +33,19 @@ void Building::computeInternalStructure(Rules& r)
 	Q_UNUSED(r);
 }
 
+/*
 QString Building::getDescription()
 {
 	QString s=tr("N:%1", "Name of the building").arg(this->name);
 
 	return s;
-}
+}*/
 
 QString Building::getDetailedDescription()
 {
-	QString s=tr("Name=%1", "The name of the building").arg(this->name);
+	QString s=tr("Building");
+	s+="\n";
+	s+=tr("Name=%1", "The name of the building").arg(this->name);
 	s+="\n";
 
 	return s;
