@@ -1,15 +1,22 @@
 //
 //
-// C++ Interface: $MODULE$
-//
-// Description: 
+// Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2003 Liviu Lalescu <http://lalescu.ro/liviu/>
 //
-// Copyright: See COPYING file that comes with this distribution
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 //
 //
+
 #ifndef ROOM_H
 #define ROOM_H
 
@@ -53,10 +60,6 @@ public:
 	Room();
 	~Room();
 	
-	/*void addEquipment(const QString& equipmentName);
-	void removeEquipment(const QString& equipmentName);
-	bool searchEquipment(const QString& equipmentName);*/
-	
 	void computeInternalStructure(Rules& r);
 
 	QString getXmlDescription();
