@@ -1,7 +1,7 @@
 /*
 File rules.h
 
-Copyright 2002, 2003 Lalescu Liviu.
+Copyright 2002-2003 Lalescu Liviu.
 
 This file is part of FET.
 
@@ -23,8 +23,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef RULES_H
 #define RULES_H
 
-#include <QCoreApplication>
-
 #include "timetable_defs.h"
 #include "timeconstraint.h"
 #include "spaceconstraint.h"
@@ -36,21 +34,33 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "room.h"
 #include "building.h"
 
+#include "matrix.h"
+
 #include <QSet>
 
-#include <qstring.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <q3ptrvector.h>
+#include <QString>
+
+#include <QCoreApplication>
+
+class FakeString
+/*
+fake string, so that the output log is not too large
+*/
+{
+public:
+	FakeString();
+
+	void operator=(const QString& other);
+	void operator=(const char* str);
+	void operator+=(const QString& other);
+	void operator+=(const char* str);
+};
 
 class QDomElement;
 
 /**
-This class contains the processed input (all the information regarding
-the faculty: teachers, students, activities, constraints, etc.)
-<p>
-Or: Structure that keeps a representation of the requirements for the
-timetable (all the input)
+This class contains all the information regarding
+the institution: teachers, students, activities, constraints, etc.
 */
 class Rules{
 	Q_DECLARE_TR_FUNCTIONS(Rules)
@@ -137,16 +147,21 @@ public:
 	*/
 	SpaceConstraintsList spaceConstraintsList;
 	
-	//The following variables contain redundant data and are used internally
+	/*
+	The following variables contain redundant data and are used internally
+	*/
 	////////////////////////////////////////////////////////////////////////
 	int nInternalTeachers;
-	Teacher* internalTeachersList[MAX_TEACHERS];
+	Matrix1D<Teacher*> internalTeachersList;
 
 	int nInternalSubjects;
-	Subject* internalSubjectsList[MAX_SUBJECTS];
+	Matrix1D<Subject*> internalSubjectsList;
+
+	int nInternalActivityTags;
+	Matrix1D<ActivityTag*> internalActivityTagsList;
 
 	int nInternalSubgroups;
-	StudentsSubgroup* internalSubgroupsList[MAX_TOTAL_SUBGROUPS];
+	Matrix1D<StudentsSubgroup*> internalSubgroupsList;
 	
 	StudentsYearsList augmentedYearsList;
 
@@ -156,25 +171,27 @@ public:
 	For speed, I used here not pointers, but static copies.
 	*/
 	int nInternalActivities;
-	Activity internalActivitiesList[MAX_ACTIVITIES];
+	Matrix1D<Activity> internalActivitiesList;
 	
 	QSet<int> inactiveActivities;
 	
-	QList<int> activitiesForSubject[MAX_SUBJECTS];
+	Matrix1D<QList<int> > activitiesForSubject;
 
 	int nInternalRooms;
-	Room* internalRoomsList[MAX_ROOMS];
+	Matrix1D<Room*> internalRoomsList;
 
 	int nInternalBuildings;
-	Building* internalBuildingsList[MAX_BUILDINGS];
+	Matrix1D<Building*> internalBuildingsList;
 
 	int nInternalTimeConstraints;
-	TimeConstraint* internalTimeConstraintsList[MAX_TIME_CONSTRAINTS];
+	Matrix1D<TimeConstraint*> internalTimeConstraintsList;
 
 	int nInternalSpaceConstraints;
-	SpaceConstraint* internalSpaceConstraintsList[MAX_SPACE_CONSTRAINTS];
+	Matrix1D<SpaceConstraint*> internalSpaceConstraintsList;
 
-	////////////////////////////////////////////////////////////////////////
+	/*
+	///////////////////////////////////////////////////////////////////////
+	*/
 
 	/**
 	True if the rules have been initialized in some way (new or loaded).
@@ -195,7 +212,7 @@ public:
 	Internal structure initializer.
 	<p>
 	After any modification of the activities or students or teachers
-	or constraints, there is a need to call this subroutine
+	or constraints, you need to call this subroutine
 	*/
 	bool computeInternalStructure();
 
@@ -213,12 +230,15 @@ public:
 	void setComments(const QString& newComments);
 
 	/**
-	Adds a new teacher to the list of teachers
+	Adds a new teacher
 	(if not already in the list).
 	Returns false/true (unsuccessful/successful).
 	*/
 	bool addTeacher(Teacher* teacher);
 
+	/*when reading rules, faster*/
+	bool addTeacherFast(Teacher* teacher);
+
 	/**
 	Returns the index of this teacher in the teachersList,
 	or -1 for inexistent teacher.
@@ -243,12 +263,17 @@ public:
 	void sortTeachersAlphabetically();
 
 	/**
-	Adds a new subject to the list of subjects
+	Adds a new subject
 	(if not already in the list).
 	Returns false/true (unsuccessful/successful).
 	*/
 	bool addSubject(Subject* subject);
 
+	/*
+	When reading rules, faster
+	*/
+	bool addSubjectFast(Subject* subject);
+
 	/**
 	Returns the index of this subject in the subjectsList,
 	or -1 if not found.
@@ -280,6 +305,11 @@ public:
 	*/
 	bool addActivityTag(ActivityTag* activityTag);
 
+	/*
+	When reading rules, faster
+	*/
+	bool addActivityTagFast(ActivityTag* activityTag);
+
 	/**
 	Returns the index of this activity tag in the activityTagsList,
 	or -1 if not found.
@@ -306,7 +336,7 @@ public:
 	void sortActivityTagsAlphabetically();
 
 	/**
-	Returns a pointer to the structure containing this student container
+	Returns a pointer to the structure containing this student set
 	(year, group or subgroup) or NULL.
 	*/
 	StudentsSet* searchStudentsSet(const QString& setName);
@@ -323,6 +353,11 @@ public:
 	Adds a new year of study to the academic structure
 	*/
 	bool addYear(StudentsYear* year);
+	
+	/*
+	When reading rules, faster
+	*/
+	bool addYearFast(StudentsYear* year);
 
 	bool removeYear(const QString& yearName);
 
@@ -348,6 +383,11 @@ public:
 	Adds a new group in a certain year of study to the academic structure
 	*/
 	bool addGroup(const QString& yearName, StudentsGroup* group);
+	
+	/*
+	When reading rules, faster
+	*/
+	bool addGroupFast(StudentsYear* year, StudentsGroup* group);
 
 	bool removeGroup(const QString& yearName, const QString& groupName);
 
@@ -376,6 +416,11 @@ public:
 	*/
 	bool addSubgroup(const QString& yearName, const QString& groupName, StudentsSubgroup* subgroup);
 
+	/*
+	When reading rules, faster
+	*/
+	bool addSubgroupFast(StudentsYear* year, StudentsGroup* group, StudentsSubgroup* subgroup);
+
 	bool removeSubgroup(const QString& yearName, const QString& groupName, const QString& subgroupName);
 
 	/**
@@ -401,7 +446,6 @@ public:
 	(It can add a subactivity of a split activity)
 	Returns true if successful or false if the maximum
 	number of activities was reached.
-	There is automatically added a ConstraintActivityPreferredTime, if necessary
 	*/
 	bool addSimpleActivity(
 		int _id,
@@ -412,20 +456,33 @@ public:
 		const QStringList& _studentsNames,
 		int _duration, /*duration, in hours*/
 		int _totalDuration,
-		//int _parity, /*parity: PARITY_WEEKLY or PARITY_FORTNIGHTLY*/
 		bool _active,
-		//int _preferredDay,
-		//int _preferredHour,
 		bool _computeNTotalStudents,
 		int _nTotalStudents);
 
+	/*
+	Faster, when reading rules (no need to recompute the number of students in activity constructor
+	*/
+	bool addSimpleActivityRulesFast(
+		int _id,
+		int _activityGroupId,
+		const QStringList& _teachersNames,
+		const QString& _subjectName,
+		const QStringList& _activityTagsNames,
+		const QStringList& _studentsNames,
+		int _duration, /*duration, in hours*/
+		int _totalDuration,
+		bool _active,
+		bool _computeNTotalStudents,
+		int _nTotalStudents,
+		int _computedNumberOfStudents);
+
 	/**
 	Adds a new split activity to the list of activities.
 	Returns true if successful or false if the maximum
 	number of activities was reached.
 	If _minDayDistance>0, there will automatically added a compulsory
 	ConstraintMinDaysBetweenActivities.
-	Also, there are automatically added several ConstraintActivityPreferredTime, if necessary
 	*/
 	bool addSplitActivity(
 		int _firstActivityId,
@@ -437,13 +494,10 @@ public:
 		int _nSplits,
 		int _totalDuration,
 		int _durations[],
-		//int _parities[],
 		bool _active[],
 		int _minDayDistance,
 		double _weightPercentage,
 		bool _consecutiveIfSameDay,
-		//int _preferredDays[],
-		//int _preferredHours[],
 		bool _computeNTotalStudents,
 		int _nTotalStudents);
 
@@ -472,11 +526,9 @@ public:
 		const QString& _subjectName, 
 		const QStringList& _activityTagsNames, 
 		const QStringList& _studentsNames,
-		//int _nTotalStudents,
 	 	int _nSplits,
 		int _totalDuration,
 		int _durations[],
-		//int _parities[],
 		bool _active[],
 		bool _computeNTotalStudents,
 		int nTotalStudents);
@@ -499,6 +551,11 @@ public:
 	*/
 	bool addRoom(Room* rm);
 
+	/*
+	Faster, when reading
+	*/
+	bool addRoomFast(Room* rm);
+
 	/**
 	Returns -1 if not found or the index in the rooms list if found.
 	*/
@@ -527,6 +584,11 @@ public:
 	*/
 	bool addBuilding(Building* rm);
 
+	/*
+	Faster, when reading
+	*/
+	bool addBuildingFast(Building* rm);
+
 	/**
 	Returns -1 if not found or the index in the buildings list if found.
 	*/
@@ -601,141 +663,141 @@ public:
 	int deactivateActivityTag(const QString& activityTagName);
 	
 private:
-	TimeConstraint* readBasicCompulsoryTime(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherNotAvailable(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherNotAvailableTimes(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readBasicCompulsoryTime(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherNotAvailable(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherNotAvailableTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readTeacherMinDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMinDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTeacherMinDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMinDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readTeacherIntervalMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersIntervalMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetIntervalMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsIntervalMaxDaysPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetNotAvailable(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetNotAvailableTimes(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readMinNDaysBetweenActivities(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readMinDaysBetweenActivities(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readMaxDaysBetweenActivities(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readMinGapsBetweenActivities(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesNotOverlapping(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesSameStartingTime(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesSameStartingHour(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesSameStartingDay(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherActivityTagMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersActivityTagMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTeacherIntervalMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersIntervalMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetIntervalMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsIntervalMaxDaysPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetNotAvailable(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetNotAvailableTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readMinNDaysBetweenActivities(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readMinDaysBetweenActivities(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readMaxDaysBetweenActivities(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readMinGapsBetweenActivities(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesNotOverlapping(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesSameStartingTime(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesSameStartingHour(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesSameStartingDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherActivityTagMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersActivityTagMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readTeacherActivityTagMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersActivityTagMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTeacherActivityTagMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersActivityTagMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readTeachersMinHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMinHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetActivityTagMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsActivityTagMaxHoursContinuously(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTeachersMinHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMinHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetActivityTagMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsActivityTagMaxHoursContinuously(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readStudentsSetActivityTagMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsActivityTagMaxHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readStudentsSetActivityTagMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsActivityTagMaxHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readStudentsMinHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetMinHoursDaily(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readStudentsMinHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetMinHoursDaily(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readActivityPreferredTime(const QDomElement& elem3, QString& xmlReadingLog,
+	TimeConstraint* readActivityPreferredTime(const QDomElement& elem3, FakeString& xmlReadingLog,
 		bool& reportUnspecifiedPermanentlyLockedTime, bool& reportUnspecifiedDayOrHourPreferredStartingTime);
-	TimeConstraint* readActivityPreferredStartingTime(const QDomElement& elem3, QString& xmlReadingLog,
+	TimeConstraint* readActivityPreferredStartingTime(const QDomElement& elem3, FakeString& xmlReadingLog,
 		bool& reportUnspecifiedPermanentlyLockedTime, bool& reportUnspecifiedDayOrHourPreferredStartingTime);
 
-	TimeConstraint* readActivityEndsStudentsDay(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesEndStudentsDay(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readActivityEndsStudentsDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesEndStudentsDay(const QDomElement& elem3, FakeString& xmlReadingLog);
 	
-	//old, with 2 and 3
-	TimeConstraint* read2ActivitiesConsecutive(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* read2ActivitiesGrouped(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* read3ActivitiesGrouped(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* read2ActivitiesOrdered(const QDomElement& elem3, QString& xmlReadingLog);
-	//end old
+	/*old, with 2 and 3*/
+	TimeConstraint* read2ActivitiesConsecutive(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* read2ActivitiesGrouped(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* read3ActivitiesGrouped(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* read2ActivitiesOrdered(const QDomElement& elem3, FakeString& xmlReadingLog);
+	/*end old*/
 	
-	TimeConstraint* readTwoActivitiesConsecutive(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTwoActivitiesGrouped(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readThreeActivitiesGrouped(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTwoActivitiesOrdered(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTwoActivitiesConsecutive(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTwoActivitiesGrouped(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readThreeActivitiesGrouped(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTwoActivitiesOrdered(const QDomElement& elem3, FakeString& xmlReadingLog);
 	
-	TimeConstraint* readActivityPreferredTimes(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivityPreferredTimeSlots(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivityPreferredStartingTimes(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readActivityPreferredTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivityPreferredTimeSlots(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivityPreferredStartingTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
 	
-	TimeConstraint* readBreak(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readBreakTimes(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readBreak(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readBreakTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
 	
-	TimeConstraint* readTeachersNoGaps(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMaxGapsPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMaxGapsPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeachersMaxGapsPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readTeacherMaxGapsPerDay(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readTeachersNoGaps(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMaxGapsPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMaxGapsPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeachersMaxGapsPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readTeacherMaxGapsPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
 	
-	TimeConstraint* readStudentsNoGaps(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetNoGaps(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsMaxGapsPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetMaxGapsPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readStudentsNoGaps(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetNoGaps(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsMaxGapsPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetMaxGapsPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readStudentsMaxGapsPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetMaxGapsPerDay(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readStudentsMaxGapsPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetMaxGapsPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readStudentsEarly(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsEarlyMaxBeginningsAtSecondHour(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetEarly(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readStudentsSetEarlyMaxBeginningsAtSecondHour(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readStudentsEarly(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsEarlyMaxBeginningsAtSecondHour(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetEarly(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readStudentsSetEarlyMaxBeginningsAtSecondHour(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readActivitiesPreferredTimes(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesPreferredTimeSlots(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readActivitiesPreferredStartingTimes(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readActivitiesPreferredTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesPreferredTimeSlots(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readActivitiesPreferredStartingTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	TimeConstraint* readSubactivitiesPreferredTimeSlots(const QDomElement& elem3, QString& xmlReadingLog);
-	TimeConstraint* readSubactivitiesPreferredStartingTimes(const QDomElement& elem3, QString& xmlReadingLog);
+	TimeConstraint* readSubactivitiesPreferredTimeSlots(const QDomElement& elem3, FakeString& xmlReadingLog);
+	TimeConstraint* readSubactivitiesPreferredStartingTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
 
 
-	SpaceConstraint* readBasicCompulsorySpace(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readRoomNotAvailable(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readRoomNotAvailableTimes(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readActivityPreferredRoom(const QDomElement& elem3, QString& xmlReadingLog,
+	SpaceConstraint* readBasicCompulsorySpace(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readRoomNotAvailable(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readRoomNotAvailableTimes(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readActivityPreferredRoom(const QDomElement& elem3, FakeString& xmlReadingLog,
 		bool& reportUnspecifiedPermanentlyLockedSpace);
-	SpaceConstraint* readActivityPreferredRooms(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectPreferredRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectPreferredRooms(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectSubjectTagPreferredRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectSubjectTagPreferredRooms(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectActivityTagPreferredRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readSubjectActivityTagPreferredRooms(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readActivityTagPreferredRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readActivityTagPreferredRooms(const QDomElement& elem3, QString& xmlReadingLog);
+	SpaceConstraint* readActivityPreferredRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectPreferredRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectPreferredRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectSubjectTagPreferredRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectSubjectTagPreferredRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectActivityTagPreferredRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readSubjectActivityTagPreferredRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readActivityTagPreferredRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readActivityTagPreferredRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	SpaceConstraint* readStudentsSetHomeRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsSetHomeRooms(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeacherHomeRoom(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeacherHomeRooms(const QDomElement& elem3, QString& xmlReadingLog);
+	SpaceConstraint* readStudentsSetHomeRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsSetHomeRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeacherHomeRoom(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeacherHomeRooms(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	SpaceConstraint* readTeacherMaxBuildingChangesPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeachersMaxBuildingChangesPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeacherMaxBuildingChangesPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeachersMaxBuildingChangesPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeacherMinGapsBetweenBuildingChanges(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readTeachersMinGapsBetweenBuildingChanges(const QDomElement& elem3, QString& xmlReadingLog);
+	SpaceConstraint* readTeacherMaxBuildingChangesPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeachersMaxBuildingChangesPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeacherMaxBuildingChangesPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeachersMaxBuildingChangesPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeacherMinGapsBetweenBuildingChanges(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readTeachersMinGapsBetweenBuildingChanges(const QDomElement& elem3, FakeString& xmlReadingLog);
 
-	SpaceConstraint* readStudentsSetMaxBuildingChangesPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsMaxBuildingChangesPerDay(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsSetMaxBuildingChangesPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsMaxBuildingChangesPerWeek(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsSetMinGapsBetweenBuildingChanges(const QDomElement& elem3, QString& xmlReadingLog);
-	SpaceConstraint* readStudentsMinGapsBetweenBuildingChanges(const QDomElement& elem3, QString& xmlReadingLog);
+	SpaceConstraint* readStudentsSetMaxBuildingChangesPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsMaxBuildingChangesPerDay(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsSetMaxBuildingChangesPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsMaxBuildingChangesPerWeek(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsSetMinGapsBetweenBuildingChanges(const QDomElement& elem3, FakeString& xmlReadingLog);
+	SpaceConstraint* readStudentsMinGapsBetweenBuildingChanges(const QDomElement& elem3, FakeString& xmlReadingLog);
 };
 
 #endif
