@@ -1,17 +1,21 @@
+/*
+File statisticsexport.cpp
+*/
+
 /***************************************************************************
                                 FET
                           -------------------
    copyright            : (C) by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************
-                      StatisticsExport.cpp  -  description
+                      statisticsexport.cpp  -  description
                              -------------------
     begin                : Sep 2008
     copyright            : (C) by Volker Dirr
                          : http://www.timetabling.de/
  ***************************************************************************
  *                                                                         *
- *   NULL program is free software; you can redistribute it and/or modify  *
+ *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
@@ -26,6 +30,28 @@
 
 // BE CAREFUL: DON'T USE INTERNAL VARIABLES HERE, because maybe computeInternalStructure() is not done!
 
+#include <QString>
+#include <QStringList>
+#include <QHash>
+#include <QMultiHash>
+#include <QMap>
+
+#include <QMessageBox>
+
+#include <QLocale>
+#include <QTime>
+#include <QDate>
+
+#include <QFile>
+#include <QTextStream>
+
+//#include <QApplication>
+#include <QProgressDialog>
+//extern QApplication* pqapplication;
+
+extern Timetable gt;
+
+
 QHash<QString, QString> hashSubjectIDsStatistics;
 QHash<QString, QString> hashActivityTagIDsStatistics;
 QHash<QString, QString> hashStudentIDsStatistics;
@@ -33,19 +59,6 @@ QHash<QString, QString> hashTeacherIDsStatistics;
 QHash<QString, QString> hashRoomIDsStatistics;
 QHash<QString, QString> hashDayIDsStatistics;
 
-#include <QMessageBox>
-
-#include <QLocale>
-#include <QTime>
-#include <QDate>
-#include <QHash>
-#include <QMap>
-
-#include <QApplication>
-#include <QProgressDialog>
-extern QApplication* pqapplication;
-
-extern Timetable gt;
 
 //extern bool simulation_running;	//needed?
 
@@ -74,6 +87,7 @@ const char SUBJECTS_TEACHERS_STATISTICS[]="subjects_teachers.html";
 const char SUBJECTS_STUDENTS_STATISTICS[]="subjects_students.html";
 const char STYLESHEET_STATISTICS[]="stylesheet.css";
 const char INDEX_STATISTICS[]="index.html";
+
 QString DIRECTORY_STATISTICS;
 QString PREFIX_STATISTICS;
 
@@ -693,6 +707,7 @@ bool StatisticsExport::exportStatisticsTeachersSubjects(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing teachers with subjects...please wait"));
 	progress.setRange(0, allSubjectsNames.count());
 	progress.setModal(true);
@@ -701,7 +716,7 @@ bool StatisticsExport::exportStatisticsTeachersSubjects(QString saveTime){
 	
 	foreach(QString subjects, allSubjectsNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
@@ -922,6 +937,7 @@ bool StatisticsExport::exportStatisticsSubjectsTeachers(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing subject with teachers...please wait"));
 	progress.setRange(0, allTeachersNames.count());
 	progress.setModal(true);
@@ -930,7 +946,7 @@ bool StatisticsExport::exportStatisticsSubjectsTeachers(QString saveTime){
 	
 	foreach(QString teachers, allTeachersNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
@@ -1149,6 +1165,7 @@ bool StatisticsExport::exportStatisticsTeachersStudents(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing teachers with students...please wait"));
 	progress.setRange(0, allStudentsNames.count());
 	progress.setModal(true);
@@ -1157,7 +1174,7 @@ bool StatisticsExport::exportStatisticsTeachersStudents(QString saveTime){
 	
 	foreach(QString students, allStudentsNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
@@ -1387,6 +1404,7 @@ bool StatisticsExport::exportStatisticsStudentsTeachers(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing students with teachers...please wait"));
 	progress.setRange(0, allTeachersNames.count());
 	progress.setModal(true);
@@ -1395,7 +1413,7 @@ bool StatisticsExport::exportStatisticsStudentsTeachers(QString saveTime){
 	
 	foreach(QString teachers, allTeachersNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
@@ -1625,6 +1643,7 @@ bool StatisticsExport::exportStatisticsSubjectsStudents(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing subjects with students...please wait"));
 	progress.setRange(0, allStudentsNames.count());
 	progress.setModal(true);
@@ -1633,7 +1652,7 @@ bool StatisticsExport::exportStatisticsSubjectsStudents(QString saveTime){
 	
 	foreach(QString students, allStudentsNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
@@ -1852,6 +1871,7 @@ bool StatisticsExport::exportStatisticsStudentsSubjects(QString saveTime){
 	tos<<"      <tbody>\n";
 	
 	QProgressDialog progress(NULL);
+	progress.setWindowTitle(tr("Exporting statistics", "Title of a progress dialog"));
 	progress.setLabelText(tr("Processing students with subjects...please wait"));
 	progress.setRange(0, allSubjectsNames.count());
 	progress.setModal(true);
@@ -1860,7 +1880,7 @@ bool StatisticsExport::exportStatisticsStudentsSubjects(QString saveTime){
 	
 	foreach(QString subjects, allSubjectsNames){
 		progress.setValue(ttt);
-		pqapplication->processEvents();
+		//pqapplication->processEvents();
 		if(progress.wasCanceled()){
 			QMessageBox::warning(NULL, tr("FET warning"), tr("Canceled"));
 			return false;
