@@ -1,17 +1,21 @@
+/*
+File statisticsexport.h
+*/
+
 /***************************************************************************
                                 FET
                           -------------------
    copyright            : (C) by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************
-                      StatisticsExport.h  -  description
+                      statisticsexport.h  -  description
                              -------------------
     begin                : Sep 2008
     copyright            : (C) by Volker Dirr
                          : http://www.timetabling.de/
  ***************************************************************************
  *                                                                         *
- *   NULL program is free software; you can redistribute it and/or modify  *
+ *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
@@ -21,6 +25,8 @@
 #ifndef STATISTICEXPORT_H
 #define STATISTICEXPORT_H
 
+#include <QString>
+
 #include "timetable.h"		//needed?
 #include "timetable_defs.h"	//needed?
 
