@@ -124,7 +124,7 @@ const int CONSTRAINT_STUDENTS_SET_ACTIVITY_TAG_MAX_HOURS_DAILY			=60;
 const int CONSTRAINT_STUDENTS_MAX_GAPS_PER_DAY							=61;
 const int CONSTRAINT_STUDENTS_SET_MAX_GAPS_PER_DAY						=62;
 
-QString getActivityDetailedDescription(const Rules& r, int id);
+QString getActivityDetailedDescription(Rules& r, int id);
 
 /**
 This class represents a time constraint
@@ -373,7 +373,8 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME];
+	QList<int> activitiesId;
+	//int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME];
 
 	/**
 	The number of activities involved in this constraint - internal structure
@@ -383,7 +384,8 @@ public:
 	/**
 	The activities involved in this constraint (indexes in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME];
+	//int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME];
+	QList<int> _activities;
 
 	ConstraintActivitiesSameStartingTime();
 
@@ -391,7 +393,8 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities' id-s.
 	*/
-	ConstraintActivitiesSameStartingTime(double wp, int n_act, const int act[]);
+	//ConstraintActivitiesSameStartingTime(double wp, int n_act, const int act[]);
+	ConstraintActivitiesSameStartingTime(double wp, int n_act, const QList<int>& act);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -439,7 +442,8 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING];
+	QList<int> activitiesId;
+	//int activitiesId[MAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING];
 
 	/**
 	The number of activities involved in this constraint - internal structure
@@ -449,7 +453,8 @@ public:
 	/**
 	The activities involved in this constraint (index in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING];
+	//int _activities[MAX_CONSTRAINT_ACTIVITIES_NOT_OVERLAPPING];
+	QList<int> _activities;
 
 	ConstraintActivitiesNotOverlapping();
 
@@ -457,7 +462,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintActivitiesNotOverlapping(double wp, int n_act, const int act[]);
+	ConstraintActivitiesNotOverlapping(double wp, int n_act, const QList<int>& act);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -506,7 +511,8 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_MIN_DAYS_BETWEEN_ACTIVITIES];
+	QList<int> activitiesId;
+	//int activitiesId[MAX_CONSTRAINT_MIN_DAYS_BETWEEN_ACTIVITIES];
 
 	/**
 	The number of minimum days between each 2 activities
@@ -523,7 +529,8 @@ public:
 	/**
 	The activities involved in this constraint (index in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_MIN_DAYS_BETWEEN_ACTIVITIES];
+	QList<int> _activities;
+	//int _activities[MAX_CONSTRAINT_MIN_DAYS_BETWEEN_ACTIVITIES];
 
 	ConstraintMinDaysBetweenActivities();
 
@@ -531,7 +538,8 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintMinDaysBetweenActivities(double wp, bool adjacentIfBroken, int n_act, const int act[], int n);
+	//ConstraintMinDaysBetweenActivities(double wp, bool adjacentIfBroken, int n_act, const int act[], int n);
+	ConstraintMinDaysBetweenActivities(double wp, bool adjacentIfBroken, int n_act, const QList<int>& act, int n);
 
 	/**
 	Comparison operator - to be sure that we do not introduce duplicates
@@ -578,7 +586,7 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_MAX_DAYS_BETWEEN_ACTIVITIES];
+	QList<int> activitiesId;
 
 	/**
 	The number of maximum days between each 2 activities
@@ -595,7 +603,7 @@ public:
 	/**
 	The activities involved in this constraint (index in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_MAX_DAYS_BETWEEN_ACTIVITIES];
+	QList<int> _activities;
 
 	ConstraintMaxDaysBetweenActivities();
 
@@ -603,7 +611,7 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintMaxDaysBetweenActivities(double wp, int n_act, const int act[], int n);
+	ConstraintMaxDaysBetweenActivities(double wp, int n_act, const QList<int>& act, int n);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -670,7 +678,8 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities.
 	*/
-	ConstraintMinGapsBetweenActivities(double wp, int n_act, const int act[], int ngaps);
+	//ConstraintMinGapsBetweenActivities(double wp, int n_act, const int act[], int ngaps);
+	ConstraintMinGapsBetweenActivities(double wp, int n_act, const QList<int>& actList, int ngaps);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1745,10 +1754,12 @@ class ConstraintStudentsMinHoursDaily: public TimeConstraint{
 
 public:
 	int minHoursDaily;
+	
+	bool allowEmptyDays;
 
 	ConstraintStudentsMinHoursDaily();
 
-	ConstraintStudentsMinHoursDaily(double wp, int minnh);
+	ConstraintStudentsMinHoursDaily(double wp, int minnh, bool _allowEmptyDays);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1783,6 +1794,8 @@ public:
 	The students set name
 	*/
 	QString students;
+	
+	bool allowEmptyDays;
 
 	//internal variables
 
@@ -1799,7 +1812,7 @@ public:
 
 	ConstraintStudentsSetMinHoursDaily();
 
-	ConstraintStudentsSetMinHoursDaily(double wp, int minnh, QString s);
+	ConstraintStudentsSetMinHoursDaily(double wp, int minnh, QString s, bool _allowEmptyDays);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1907,17 +1920,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int p_nPreferredTimeSlots;
+	int p_nPreferredTimeSlots_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int p_days[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_TIME_SLOTS];
+	//int p_days[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_TIME_SLOTS];
+	QList<int> p_days_L;
 
 	/**
 	The preferred hour. If -1, then the user does not care about the hour.
 	*/
-	int p_hours[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_TIME_SLOTS];
+	//int p_hours[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_TIME_SLOTS];
+	QList<int> p_hours_L;
 
 	//internal variables
 	/**
@@ -1927,7 +1942,8 @@ public:
 
 	ConstraintActivityPreferredTimeSlots();
 
-	ConstraintActivityPreferredTimeSlots(double wp, int actId, int nPT, int d[], int h[]);
+	//ConstraintActivityPreferredTimeSlots(double wp, int actId, int nPT, int d[], int h[]);
+	ConstraintActivityPreferredTimeSlots(double wp, int actId, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -1964,17 +1980,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int nPreferredStartingTimes;
+	int nPreferredStartingTimes_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int days[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIMES];
+	//int days[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIMES];
+	QList<int> days_L;
 
 	/**
 	The preferred hour. If -1, then the user does not care about the hour.
 	*/
-	int hours[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIMES];
+	//int hours[MAX_N_CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIMES];
+	QList<int> hours_L;
 
 	//internal variables
 	/**
@@ -1984,7 +2002,8 @@ public:
 
 	ConstraintActivityPreferredStartingTimes();
 
-	ConstraintActivityPreferredStartingTimes(double wp, int actId, int nPT, int d[], int h[]);
+	//ConstraintActivityPreferredStartingTimes(double wp, int actId, int nPT, int d[], int h[]);
+	ConstraintActivityPreferredStartingTimes(double wp, int actId, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2043,17 +2062,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int p_nPreferredTimeSlots;
+	int p_nPreferredTimeSlots_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int p_days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	//int p_days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	QList<int> p_days_L;
 
 	/**
 	The preferred hours. If -1, then the user does not care about the hour.
 	*/
-	int p_hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	//int p_hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	QList<int> p_hours_L;
 
 	//internal variables
 	
@@ -2066,12 +2087,15 @@ public:
 	The indices of the activities in the rules (from 0 to rules.nActivities-1)
 	These are indices in the internal list -> Rules::internalActivitiesList
 	*/
-	int p_activitiesIndices[MAX_ACTIVITIES];
+	//int p_activitiesIndices[MAX_ACTIVITIES];
+	QList<int> p_activitiesIndices;
 
 	ConstraintActivitiesPreferredTimeSlots();
 
+	//ConstraintActivitiesPreferredTimeSlots(double wp, QString te,
+	//	QString st, QString su, QString sut, int nPT, int d[], int h[]);
 	ConstraintActivitiesPreferredTimeSlots(double wp, QString te,
-		QString st, QString su, QString sut, int nPT, int d[], int h[]);
+		QString st, QString su, QString sut, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2125,17 +2149,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int p_nPreferredTimeSlots;
+	int p_nPreferredTimeSlots_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int p_days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	//int p_days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	QList<int> p_days_L;
 
 	/**
 	The preferred hours. If -1, then the user does not care about the hour.
 	*/
-	int p_hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	//int p_hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_TIME_SLOTS];
+	QList<int> p_hours_L;
 
 	//internal variables
 	
@@ -2148,12 +2174,15 @@ public:
 	The indices of the activities in the rules (from 0 to rules.nActivities-1)
 	These are indices in the internal list -> Rules::internalActivitiesList
 	*/
-	int p_activitiesIndices[MAX_ACTIVITIES];
+	//int p_activitiesIndices[MAX_ACTIVITIES];
+	QList<int> p_activitiesIndices;
 
 	ConstraintSubactivitiesPreferredTimeSlots();
 
+	//ConstraintSubactivitiesPreferredTimeSlots(double wp, int compNo, QString te,
+	//	QString st, QString su, QString sut, int nPT, int d[], int h[]);
 	ConstraintSubactivitiesPreferredTimeSlots(double wp, int compNo, QString te,
-		QString st, QString su, QString sut, int nPT, int d[], int h[]);
+		QString st, QString su, QString sut, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2205,17 +2234,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int nPreferredStartingTimes;
+	int nPreferredStartingTimes_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_STARTING_TIMES];
+	//int days[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_STARTING_TIMES];
+	QList<int> days_L;
 
 	/**
 	The preferred hours. If -1, then the user does not care about the hour.
 	*/
-	int hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_STARTING_TIMES];
+	//int hours[MAX_N_CONSTRAINT_ACTIVITIES_PREFERRED_STARTING_TIMES];
+	QList<int> hours_L;
 
 	//internal variables
 	
@@ -2228,12 +2259,15 @@ public:
 	The indices of the activities in the rules (from 0 to rules.nActivities-1)
 	These are indices in the internal list -> Rules::internalActivitiesList
 	*/
-	int activitiesIndices[MAX_ACTIVITIES];
+	//int activitiesIndices[MAX_ACTIVITIES];
+	QList<int> activitiesIndices;
 
 	ConstraintActivitiesPreferredStartingTimes();
 
+	//ConstraintActivitiesPreferredStartingTimes(double wp, QString te,
+	//	QString st, QString su, QString sut, int nPT, int d[], int h[]);
 	ConstraintActivitiesPreferredStartingTimes(double wp, QString te,
-		QString st, QString su, QString sut, int nPT, int d[], int h[]);
+		QString st, QString su, QString sut, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2287,17 +2321,19 @@ public:
 	/**
 	The number of preferred times
 	*/
-	int nPreferredStartingTimes;
+	int nPreferredStartingTimes_L;
 
 	/**
 	The preferred days. If -1, then the user does not care about the day.
 	*/
-	int days[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_STARTING_TIMES];
+	//int days[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_STARTING_TIMES];
+	QList<int> days_L;
 
 	/**
 	The preferred hours. If -1, then the user does not care about the hour.
 	*/
-	int hours[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_STARTING_TIMES];
+	//int hours[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_STARTING_TIMES];
+	QList<int> hours_L;
 
 	//internal variables
 	
@@ -2310,12 +2346,13 @@ public:
 	The indices of the activities in the rules (from 0 to rules.nActivities-1)
 	These are indices in the internal list -> Rules::internalActivitiesList
 	*/
-	int activitiesIndices[MAX_ACTIVITIES];
+	//int activitiesIndices[MAX_ACTIVITIES];
+	QList<int> activitiesIndices;
 
 	ConstraintSubactivitiesPreferredStartingTimes();
 
 	ConstraintSubactivitiesPreferredStartingTimes(double wp, int compNo, QString te,
-		QString st, QString su, QString sut, int nPT, int d[], int h[]);
+		QString st, QString su, QString sut, int nPT_L, QList<int> d_L, QList<int> h_L);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2365,7 +2402,8 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR];
+	QList<int> activitiesId;
+	//int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR];
 
 	/**
 	The number of activities involved in this constraint - internal structure
@@ -2375,7 +2413,8 @@ public:
 	/**
 	The activities involved in this constraint (index in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR];
+	QList<int> _activities;
+	//int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR];
 
 	ConstraintActivitiesSameStartingHour();
 
@@ -2383,7 +2422,8 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities' id-s.
 	*/
-	ConstraintActivitiesSameStartingHour(double wp, int n_act, const int act[]);
+	//ConstraintActivitiesSameStartingHour(double wp, int n_act, const int act[]);
+	ConstraintActivitiesSameStartingHour(double wp, int n_act, const QList<int>& act);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2425,7 +2465,8 @@ public:
 	/**
 	The activities involved in this constraint (id)
 	*/
-	int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_DAY];
+	QList<int> activitiesId;
+	//int activitiesId[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_DAY];
 
 	/**
 	The number of activities involved in this constraint - internal structure
@@ -2435,7 +2476,8 @@ public:
 	/**
 	The activities involved in this constraint (index in the rules) - internal structure
 	*/
-	int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_DAY];
+	//int _activities[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_DAY];
+	QList<int> _activities;
 
 	ConstraintActivitiesSameStartingDay();
 
@@ -2443,7 +2485,8 @@ public:
 	Constructor, using:
 	the weight, the number of activities and the list of activities' id-s.
 	*/
-	ConstraintActivitiesSameStartingDay(double wp, int n_act, const int act[]);
+	//ConstraintActivitiesSameStartingDay(double wp, int n_act, const int act[]);
+	ConstraintActivitiesSameStartingDay(double wp, int n_act, const QList<int>& act);
 
 	bool computeInternalStructure(Rules& r);
 
@@ -2735,10 +2778,12 @@ public:
 	The minimum hours daily
 	*/
 	int minHoursDaily;
+	
+	bool allowEmptyDays;
 
 	ConstraintTeachersMinHoursDaily();
 
-	ConstraintTeachersMinHoursDaily(double wp, int minhours);
+	ConstraintTeachersMinHoursDaily(double wp, int minhours, bool _allowEmptyDays);
 
 	QString getXmlDescription(Rules& r);
 
@@ -2775,10 +2820,12 @@ public:
 	QString teacherName;
 	
 	int teacher_ID;
+	
+	bool allowEmptyDays;
 
 	ConstraintTeacherMinHoursDaily();
 
-	ConstraintTeacherMinHoursDaily(double wp, int minhours, const QString& teacher);
+	ConstraintTeacherMinHoursDaily(double wp, int minhours, const QString& teacher, bool _allowEmptyDays);
 
 	QString getXmlDescription(Rules& r);
 
@@ -3029,7 +3076,8 @@ public:
 	The indices of the activities in the rules (from 0 to rules.nActivities-1)
 	These are indices in the internal list -> Rules::internalActivitiesList
 	*/
-	int activitiesIndices[MAX_ACTIVITIES];
+	//int activitiesIndices[MAX_ACTIVITIES];
+	QList<int> activitiesIndices;
 
 	ConstraintActivitiesEndStudentsDay();
 
