@@ -1,15 +1,22 @@
 //
 //
-// C++ Implementation: $MODULE$
-//
-// Description:
+// Description: This file is part of FET
 //
 //
-// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2005
+// Author: Lalescu Liviu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2005 Liviu Lalescu <http://lalescu.ro/liviu/>
 //
-// Copyright: See COPYING file that comes with this distribution
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 //
 //
+
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
@@ -20,11 +27,7 @@
 #include "subject.h"
 #include "activitytag.h"
 
-#include <q3listbox.h>
-#include <qinputdialog.h>
-#include <q3textedit.h>
-
-#include <QDesktopWidget>
+#include <QInputDialog>
 
 #include <QMessageBox>
 
@@ -171,7 +174,8 @@ void ActivityTagsForm::sortActivityTags()
 void ActivityTagsForm::activityTagChanged(int index)
 {
 	if(index<0){
-		currentActivityTagTextEdit->setText(tr("Invalid activity tag"));
+		//currentActivityTagTextEdit->setText(tr("Invalid activity tag"));
+		currentActivityTagTextEdit->setText("");
 		return;
 	}
 	
