@@ -24,25 +24,23 @@
 #include "timetable.h"
 #include "fet.h"
 
-//#include "fetmainform.h"
-
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
+#include <QList>
 
 class AddActivityForm : public QDialog, Ui::AddActivityForm_template  {
 	Q_OBJECT
+	
+private:
+	QList<QSpinBox*> durList;
+	QList<QCheckBox*> activList;
 
-public: 
+	//QWidget* subTab(int i);
+	QSpinBox* dur(int i);
+	QCheckBox* activ(int i);
+
+public:
 	QList<QString> canonicalStudentsSetsNames;
 
-	AddActivityForm();
+	AddActivityForm(const QString& teacherName, const QString& studentsSetName, const QString& subjectName, const QString& activityTagName);
 	~AddActivityForm();
 
 	void updateStudentsListBox();
