@@ -17,15 +17,8 @@
 
 #include "addbuildingform.h"
 
-#include <qlineedit.h>
-#include <q3combobox.h>
-
-#include <QDesktopWidget>
-
 #include <QMessageBox>
 
-#include <QTextEdit>
-
 AddBuildingForm::AddBuildingForm()
 {
     setupUi(this);
