@@ -23,15 +23,6 @@
 #include "timetable.h"
 #include "fet.h"
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
 #include <QList>
 
 class AddConstraintActivityEndsStudentsDayForm : public QDialog, Ui::AddConstraintActivityEndsStudentsDayForm_template  {
