@@ -15,17 +15,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "longtextmessagebox.h"
 
 #include "addconstraintbasiccompulsoryspaceform.h"
 #include "timeconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 AddConstraintBasicCompulsorySpaceForm::AddConstraintBasicCompulsorySpaceForm()
 {
     setupUi(this);
@@ -96,7 +94,8 @@ void AddConstraintBasicCompulsorySpaceForm::addCurrentConstraint()
 			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
 	else{
 		QMessageBox::warning(this, tr("FET information"),
-			tr("Constraint NOT added - please report error"));
+			tr("Constraint NOT added - there must be another constraint of this "
+			  "type. Please edit that one"));
 		delete ctr;
 	}
 }
