@@ -15,17 +15,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "longtextmessagebox.h"
 
 #include "addconstraintstudentsminhoursdailyform.h"
 #include "timeconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 AddConstraintStudentsMinHoursDailyForm::AddConstraintStudentsMinHoursDailyForm()
 {
     setupUi(this);
@@ -43,6 +41,11 @@ AddConstraintStudentsMinHoursDailyForm::AddConstraintStudentsMinHoursDailyForm()
 	move(xx, yy);*/
 	centerWidgetOnScreen(this);
 	
+	if(ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS)
+		allowLabel->setText(tr("Advanced usage: enabled"));
+	else
+		allowLabel->setText(tr("Avdanced usage: not enabled"));
+	
 	minHoursSpinBox->setMinValue(1);
 	minHoursSpinBox->setMaxValue(gt.rules.nHoursPerDay);
 	minHoursSpinBox->setValue(1);
@@ -94,6 +97,16 @@ void AddConstraintStudentsMinHoursDailyForm::addCurrentConstraint()
 		return;
 	}
 	
+	if(!ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS && allowEmptyDaysCheckBox->isChecked()){
+		QMessageBox::warning(this, tr("FET warning"), tr("Empty days for students min hours daily constraints are not enabled. You must enable them from the Settings->Advanced menu."));
+		return;
+	}
+	
+	if(allowEmptyDaysCheckBox->isChecked() && minHoursSpinBox->value()<2){
+		QMessageBox::warning(this, tr("FET warning"), tr("If you allow empty days, the min hours must be at least 2 (to make it a non-trivial constraint)"));
+		return;
+	}
+	
 /*	if(minHoursSpinBox->value()<1){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid min hours - must be >= 1"));
@@ -102,7 +115,7 @@ void AddConstraintStudentsMinHoursDailyForm::addCurrentConstraint()
 
 	int minHours=minHoursSpinBox->value();
 
-	ctr=new ConstraintStudentsMinHoursDaily(weight, /*compulsory,*/ minHours);
+	ctr=new ConstraintStudentsMinHoursDaily(weight, /*compulsory,*/ minHours, allowEmptyDaysCheckBox->isChecked());
 
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	if(tmp2)
@@ -114,3 +127,20 @@ void AddConstraintStudentsMinHoursDailyForm::addCurrentConstraint()
 		delete ctr;
 	}
 }
+
+void AddConstraintStudentsMinHoursDailyForm::on_allowEmptyDaysCheckBox_toggled()
+{
+	bool k=allowEmptyDaysCheckBox->isChecked();
+	
+	if(k && !ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS){
+		allowEmptyDaysCheckBox->setChecked(false);
+		QString s=tr("Advanced usage is not enabled. To be able to select 'Allow empty days' for the constraints of type min hours daily for students, you must enable the option from the Settings->Advanced menu.",
+			"'Allow empty days' is an option which the user can enable and then he can select it.");
+		s+="\n\n";
+		s+=tr("Explanation: only select this option if your institution allows empty days for students and a timetable is possible with empty days for students."
+			" Otherwise, it is IMPERATIVE (for performance reasons) to not select this option (or FET may not be able to find a timetable).");
+		s+="\n\n";
+		s+=tr("Use with caution.");
+		QMessageBox::information(this, tr("FET information"), s);
+	}
+}
