@@ -22,16 +22,6 @@
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
-//#include "fetmainform.h"
-
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
 
 class AddConstraintStudentsMinHoursDailyForm : public QDialog, Ui::AddConstraintStudentsMinHoursDailyForm_template  {
 	Q_OBJECT
@@ -42,6 +32,8 @@ public:
 public slots:
 	void constraintChanged();
 	void addCurrentConstraint();
+	
+	void on_allowEmptyDaysCheckBox_toggled();
 };
 
 #endif
