@@ -15,18 +15,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "longtextmessagebox.h"
 
 #include "addconstraintsubjectpreferredroomsform.h"
 #include "spaceconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <q3table.h>
-
-#include <QDesktopWidget>
-
 AddConstraintSubjectPreferredRoomsForm::AddConstraintSubjectPreferredRoomsForm()
 {
     setupUi(this);
