@@ -23,15 +23,6 @@
 #include "timetable.h"
 #include "fet.h"
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
 class AddConstraintTeachersMinHoursDailyForm : public QDialog, Ui::AddConstraintTeachersMinHoursDailyForm_template  {
 	Q_OBJECT
 public:
@@ -43,6 +34,8 @@ public:
 public slots:
 	void constraintChanged();
 	void addCurrentConstraint();
+
+	void on_allowEmptyDaysCheckBox_toggled();
 };
 
 #endif
