@@ -19,11 +19,6 @@
 
 #include "longtextmessagebox.h"
 
-#include <qlineedit.h>
-#include <q3combobox.h>
-
-#include <QDesktopWidget>
-
 #include <QMessageBox>
 
 #include <QTextEdit>
