@@ -24,13 +24,6 @@
 #include "timetable.h"
 #include "fet.h"
 
-//#include "fetmainform.h"
-
-#include <qspinbox.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
-
 class AddRoomForm : public QDialog, Ui::AddRoomForm_template {
 	Q_OBJECT
 public: 
