@@ -17,10 +17,6 @@
 
 #include "addstudentsgroupform.h"
 
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 #include <QMessageBox>
 
 AddStudentsGroupForm::AddStudentsGroupForm(const QString& yearName)
@@ -82,11 +78,12 @@ void AddStudentsGroupForm::addStudentsGroup()
 	if(ss!=NULL){ //already existing group, but in other year. It is the same group.
 		assert(ss->type==STUDENTS_GROUP);
 		if(QMessageBox::warning( this, tr("FET"),
-			tr("This group already exists, but in another year\n"
-			"If you insert current group to current year, that\n"
-			"means that some years share the same group (overlap)\n"
-			"If you want to make a new group, independent,\n"
-			"please abort now and give it another name\n"),
+			tr("This group already exists, but in another year. "
+			"If you insert current group to current year, that "
+			"means that some years share the same group (overlap). "
+			"If you want to make a new group, independent, "
+			"please abort now and give it another name.")+"\n\n"+tr("Note: the number of students for the added group will be the number of students of the already existing group"
+			" (you can modify the number of students in the modify group dialog)."),
 			tr("Add"),tr("Abort"), 0, 0, 1 ) == 1)
 			return;
 
