@@ -17,10 +17,6 @@
 
 #include "addstudentssubgroupform.h"
 
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 #include <QMessageBox>
 
 AddStudentsSubgroupForm::AddStudentsSubgroupForm(const QString& yearName, const QString& groupName)
@@ -83,11 +79,12 @@ void AddStudentsSubgroupForm::addStudentsSubgroup()
 	if(ss!=NULL){ //already existing subgroup, but in other group. Several groups share the same subgroup.
 		assert(ss->type==STUDENTS_SUBGROUP);
 		if(QMessageBox::warning( this, tr("FET"),
-			tr("This subgroup already exists, but in another group\n"
-			"If you insert current subgroup to current group, that\n"
-			"means that some groups share the same subgroup (overlap)\n"
-			"If you want to make a new subgroup, independent,\n"
-			"please abort now and give it another name\n"),
+			tr("This subgroup already exists, but in another group. "
+			"If you insert current subgroup to current group, that "
+			"means that some groups share the same subgroup (overlap). "
+			"If you want to make a new subgroup, independent, "
+			"please abort now and give it another name.")+"\n\n"+tr("Note: the number of students for the added subgroup will be the number of students of the already existing subgroup "
+			"(you can modify the number of students in the modify subgroup dialog)."),
 			tr("Add"), tr("Abort"), 0, 0, 1 ) == 1)
 			return;
 
