@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintactivitiespreferredtimeslotsform.h"
 #include "addconstraintactivitiespreferredtimeslotsform.h"
 #include "modifyconstraintactivitiespreferredtimeslotsform.h"
 
-#include <QDesktopWidget>
-
 ConstraintActivitiesPreferredTimeSlotsForm::ConstraintActivitiesPreferredTimeSlotsForm()
 {
     setupUi(this);
@@ -77,8 +77,10 @@ bool ConstraintActivitiesPreferredTimeSlotsForm::filterOk(TimeConstraint* ctr)
 
 void ConstraintActivitiesPreferredTimeSlotsForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	QString s;
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
