@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintactivitypreferredroomsform.h"
 #include "addconstraintactivitypreferredroomsform.h"
 #include "modifyconstraintactivitypreferredroomsform.h"
 
-#include <QDesktopWidget>
-
 ConstraintActivityPreferredRoomsForm::ConstraintActivityPreferredRoomsForm()
 {
     setupUi(this);
@@ -113,10 +113,13 @@ void ConstraintActivityPreferredRoomsForm::filterChanged()
 		}
 	}
 
-	if(visibleConstraintsList.count()>0)
+	constraintsListBox->setCurrentItem(0);
+	this->constraintChanged(constraintsListBox->currentItem());
+
+	/*if(visibleConstraintsList.count()>0)
 		constraintChanged(0);
 	else
-		constraintChanged(-1);
+		constraintChanged(-1);*/
 }
 
 bool ConstraintActivityPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
@@ -185,7 +188,8 @@ bool ConstraintActivityPreferredRoomsForm::filterOk(SpaceConstraint* ctr)
 void ConstraintActivityPreferredRoomsForm::constraintChanged(int index)
 {
 	if(index<0){
-		currentConstraintTextEdit->setText(tr("Invalid constraint"));
+		currentConstraintTextEdit->setText("");
+		//currentConstraintTextEdit->setText(tr("Invalid constraint"));
 		return;
 	}
 	QString s;
