@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintsubactivitiespreferredstartingtimesform.h"
 #include "addconstraintsubactivitiespreferredstartingtimesform.h"
 #include "modifyconstraintsubactivitiespreferredstartingtimesform.h"
 
-#include <QDesktopWidget>
-
 ConstraintSubactivitiesPreferredStartingTimesForm::ConstraintSubactivitiesPreferredStartingTimesForm()
 {
     setupUi(this);
@@ -79,8 +79,10 @@ bool ConstraintSubactivitiesPreferredStartingTimesForm::filterOk(TimeConstraint*
 
 void ConstraintSubactivitiesPreferredStartingTimesForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	QString s;
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
