@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintteacheractivitytagmaxhourscontinuouslyform.h"
 #include "addconstraintteacheractivitytagmaxhourscontinuouslyform.h"
 #include "modifyconstraintteacheractivitytagmaxhourscontinuouslyform.h"
 
-#include <QDesktopWidget>
-
 ConstraintTeacherActivityTagMaxHoursContinuouslyForm::ConstraintTeacherActivityTagMaxHoursContinuouslyForm()
 {
     setupUi(this);
@@ -91,12 +91,17 @@ void ConstraintTeacherActivityTagMaxHoursContinuouslyForm::filterChanged()
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
 	}
+	
+	constraintsListBox->setCurrentItem(0);
+	this->constraintChanged(constraintsListBox->currentItem());
 }
 
 void ConstraintTeacherActivityTagMaxHoursContinuouslyForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
