@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintteacherintervalmaxdaysperweekform.h"
 #include "addconstraintteacherintervalmaxdaysperweekform.h"
 #include "modifyconstraintteacherintervalmaxdaysperweekform.h"
 
-#include <QDesktopWidget>
-
 ConstraintTeacherIntervalMaxDaysPerWeekForm::ConstraintTeacherIntervalMaxDaysPerWeekForm()
 {
     setupUi(this);
@@ -81,12 +81,17 @@ void ConstraintTeacherIntervalMaxDaysPerWeekForm::filterChanged()
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
 	}
+
+	constraintsListBox->setCurrentItem(0);
+	this->constraintChanged(constraintsListBox->currentItem());
 }
 
 void ConstraintTeacherIntervalMaxDaysPerWeekForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
