@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintteachersactivitytagmaxhourscontinuouslyform.h"
 #include "addconstraintteachersactivitytagmaxhourscontinuouslyform.h"
 #include "modifyconstraintteachersactivitytagmaxhourscontinuouslyform.h"
 
-#include <QDesktopWidget>
-
 ConstraintTeachersActivityTagMaxHoursContinuouslyForm::ConstraintTeachersActivityTagMaxHoursContinuouslyForm()
 {
     setupUi(this);
@@ -80,12 +80,17 @@ void ConstraintTeachersActivityTagMaxHoursContinuouslyForm::filterChanged()
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
 	}
+
+	constraintsListBox->setCurrentItem(0);
+	this->constraintChanged(constraintsListBox->currentItem());
 }
 
 void ConstraintTeachersActivityTagMaxHoursContinuouslyForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
