@@ -15,14 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
 #include "longtextmessagebox.h"
 
 #include "constraintteachersmaxhoursdailyform.h"
 #include "addconstraintteachersmaxhoursdailyform.h"
 #include "modifyconstraintteachersmaxhoursdailyform.h"
 
-#include <QDesktopWidget>
-
 ConstraintTeachersMaxHoursDailyForm::ConstraintTeachersMaxHoursDailyForm()
 {
     setupUi(this);
@@ -69,12 +69,17 @@ void ConstraintTeachersMaxHoursDailyForm::filterChanged()
 			constraintsListBox->insertItem(ctr->getDescription(gt.rules));
 		}
 	}
+
+	constraintsListBox->setCurrentItem(0);
+	this->constraintChanged(constraintsListBox->currentItem());
 }
 
 void ConstraintTeachersMaxHoursDailyForm::constraintChanged(int index)
 {
-	if(index<0)
+	if(index<0){
+		currentConstraintTextEdit->setText("");
 		return;
+	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
 	assert(ctr!=NULL);
