@@ -15,18 +15,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "modifyconstraintactivitiessamestartingtimeform.h"
 #include "spaceconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <q3table.h>
-
 #include <QList>
 
-#include <QDesktopWidget>
-
 ModifyConstraintActivitiesSameStartingTimeForm::ModifyConstraintActivitiesSameStartingTimeForm(ConstraintActivitiesSameStartingTime* ctr)
 {
     setupUi(this);
@@ -210,16 +207,19 @@ void ModifyConstraintActivitiesSameStartingTimeForm::ok()
 			tr("Only one selected activity"));
 		return;
 	}
-	if(this->selectedActivitiesList.size()>MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME){
+	/*if(this->selectedActivitiesList.size()>MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Please report error to the author\nMAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_TIME must be increased (you have too many activities)"));
 		return;
-	}
+	}*/
 	
 	int i;
 	QList<int>::iterator it;
-	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++)
-		this->_ctr->activitiesId[i]=*it;
+	this->_ctr->activitiesId.clear();
+	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++){
+		//this->_ctr->activitiesId[i]=*it;
+		this->_ctr->activitiesId.append(*it);
+	}
 	this->_ctr->n_activities=i;
 		
 	this->_ctr->weightPercentage=weight;
