@@ -22,16 +22,6 @@
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
-//#include "fetmainform.h"
-
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
 
 class ModifyConstraintStudentsMinHoursDailyForm : public QDialog, Ui::ModifyConstraintStudentsMinHoursDailyForm_template  {
 	Q_OBJECT
@@ -45,6 +35,8 @@ public slots:
 	void constraintChanged();
 	void ok();
 	void cancel();
+
+	void allowEmptyDaysCheckBoxToggled();
 };
 
 #endif
