@@ -15,15 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "modifyconstraintstudentssetminhoursdailyform.h"
 #include "timeconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 ModifyConstraintStudentsSetMinHoursDailyForm::ModifyConstraintStudentsSetMinHoursDailyForm(ConstraintStudentsSetMinHoursDaily* ctr)
 {
     setupUi(this);
@@ -51,6 +49,15 @@ ModifyConstraintStudentsSetMinHoursDailyForm::ModifyConstraintStudentsSetMinHour
 	//compulsoryCheckBox->setChecked(ctr->compulsory);
 	weightLineEdit->setText(QString::number(ctr->weightPercentage));
 	
+	allowEmptyDaysCheckBox->setChecked(ctr->allowEmptyDays);
+	
+	connect(allowEmptyDaysCheckBox, SIGNAL(toggled(bool)), this, SLOT(allowEmptyDaysCheckBoxToggled())); //after set checked!
+	
+	if(ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS)
+		allowLabel->setText(tr("Advanced usage: enabled"));
+	else
+		allowLabel->setText(tr("Advanced usage: not enabled"));
+	
 	updateStudentsComboBox();
 
 	minHoursSpinBox->setMinValue(1);
@@ -135,6 +142,16 @@ void ModifyConstraintStudentsSetMinHoursDailyForm::ok()
 		return;
 	}
 
+	if(!ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS && allowEmptyDaysCheckBox->isChecked()){
+		QMessageBox::warning(this, tr("FET warning"), tr("Empty days for students min hours daily constraints are not enabled. You must enable them from the Settings->Advanced menu."));
+		return;
+	}
+
+	if(allowEmptyDaysCheckBox->isChecked() && minHoursSpinBox->value()<2){
+		QMessageBox::warning(this, tr("FET warning"), tr("If you allow empty days, the min hours must be at least 2 (to make it a non-trivial constraint)"));
+		return;
+	}
+
 	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
 		compulsory=true;*/
@@ -153,6 +170,8 @@ void ModifyConstraintStudentsSetMinHoursDailyForm::ok()
 	//this->_ctr->minHoursDaily=minHoursSpinBox->value();
 	this->_ctr->minHoursDaily=minHoursSpinBox->value();
 
+	this->_ctr->allowEmptyDays=allowEmptyDaysCheckBox->isChecked();
+
 	gt.rules.internalStructureComputed=false;
 	
 	this->close();
@@ -162,3 +181,20 @@ void ModifyConstraintStudentsSetMinHoursDailyForm::cancel()
 {
 	this->close();
 }
+
+void ModifyConstraintStudentsSetMinHoursDailyForm::allowEmptyDaysCheckBoxToggled()
+{
+	bool k=allowEmptyDaysCheckBox->isChecked();
+		
+	if(k && !ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS){
+		allowEmptyDaysCheckBox->setChecked(false);
+		QString s=tr("Advanced usage is not enabled. To be able to select 'Allow empty days' for the constraints of type min hours daily for students, you must enable the option from the Settings->Advanced menu.",
+			"'Allow empty days' is an option which the user can enable and then he can select it.");
+		s+="\n\n";
+		s+=tr("Explanation: only select this option if your institution allows empty days for students and a timetable is possible with empty days for students."
+			" Otherwise, it is IMPERATIVE (for performance reasons) to not select this option (or FET may not be able to find a timetable).");
+		s+="\n\n";
+		s+=tr("Use with caution.");
+		QMessageBox::information(this, tr("FET information"), s);
+	}
+}
