@@ -15,17 +15,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <QMessageBox>
+
+#include <cstdio>
+
 #include "tablewidgetupdatebug.h"
 
 #include "modifyconstraintsubactivitiespreferredtimeslotsform.h"
 #include "timeconstraint.h"
 
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-
-#include <QDesktopWidget>
-
 #include <QHeaderView>
 #include <QTableWidget>
 #include <QTableWidgetItem>
@@ -38,6 +36,8 @@
 #define YES		(QString(" "))
 #define NO		(QString("X"))
 
+//static bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
+
 ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ModifyConstraintSubactivitiesPreferredTimeSlotsForm(ConstraintSubactivitiesPreferredTimeSlots* ctr)
 {
     setupUi(this);
@@ -74,7 +74,7 @@ ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ModifyConstraintSubactiviti
 	updateActivityTagsComboBox();
 	
 	componentNumberSpinBox->setMinValue(1);
-	componentNumberSpinBox->setMaxValue(99);
+	componentNumberSpinBox->setMaxValue(MAX_SPLIT_OF_AN_ACTIVITY);
 	componentNumberSpinBox->setValue(this->_ctr->componentNumber);
 	
 	preferredTimesTable->setRowCount(gt.rules.nHoursPerDay);
@@ -89,15 +89,17 @@ ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ModifyConstraintSubactiviti
 		preferredTimesTable->setVerticalHeaderItem(i, item);
 	}
 
-	bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
+	Matrix2D<bool> currentMatrix;
+	currentMatrix.resize(gt.rules.nHoursPerDay, gt.rules.nDaysPerWeek);
+	//bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	for(int i=0; i<gt.rules.nHoursPerDay; i++)
 		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
 			currentMatrix[i][j]=false;
-	for(int k=0; k<ctr->p_nPreferredTimeSlots; k++){
-		if(ctr->p_hours[k]==-1 || ctr->p_days[k]==-1)
+	for(int k=0; k<ctr->p_nPreferredTimeSlots_L; k++){
+		if(ctr->p_hours_L[k]==-1 || ctr->p_days_L[k]==-1)
 			assert(0);
-		int i=ctr->p_hours[k];
-		int j=ctr->p_days[k];
+		int i=ctr->p_hours_L[k];
+		int j=ctr->p_days_L[k];
 		currentMatrix[i][j]=true;
 	}
 
@@ -379,13 +381,15 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ok()
 				return;
 	}*/
 
-	int days[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS];
-	int hours[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS];
+	QList<int> days_L;
+	QList<int> hours_L;
+	//int days[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS];
+	//int hours[MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS];
 	int n=0;
 	for(int j=0; j<gt.rules.nDaysPerWeek; j++)
 		for(int i=0; i<gt.rules.nHoursPerDay; i++)
 			if(preferredTimesTable->item(i, j)->text()==YES){
-				if(n>=MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS){
+				/*if(n>=MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS){
 					QString s=tr("Not enough slots (too many \"Yes\" values).");
 					s+="\n";
 					s+=tr("Please increase the variable MAX_N_CONSTRAINT_SUBACTIVITIES_PREFERRED_TIME_SLOTS");
@@ -394,10 +398,10 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ok()
 					QMessageBox::critical(this, tr("FET information"), s);
 					
 					return;
-				}
+				}*/
 				
-				days[n]=j;
-				hours[n]=i;
+				days_L.append(j);
+				hours_L.append(i);
 				n++;
 			}
 
@@ -419,11 +423,13 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ok()
 	this->_ctr->p_studentsName=students;
 	this->_ctr->p_subjectName=subject;
 	this->_ctr->p_activityTagName=activityTag;
-	this->_ctr->p_nPreferredTimeSlots=n;
-	for(int i=0; i<n; i++){
+	this->_ctr->p_nPreferredTimeSlots_L=n;
+	/*for(int i=0; i<n; i++){
 		this->_ctr->p_days[i]=days[i];
 		this->_ctr->p_hours[i]=hours[i];
-	}
+	}*/
+	this->_ctr->p_days_L=days_L;
+	this->_ctr->p_hours_L=hours_L;
 
 	gt.rules.internalStructureComputed=false;
 	
