@@ -23,15 +23,6 @@
 #include "timetable.h"
 #include "fet.h"
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
 class ModifyConstraintTeacherMinHoursDailyForm : public QDialog, Ui::ModifyConstraintTeacherMinHoursDailyForm_template  {
 	Q_OBJECT
 public:
@@ -46,6 +37,8 @@ public slots:
 	void constraintChanged();
 	void ok();
 	void cancel();
+
+	void allowEmptyDaysCheckBoxToggled();
 };
 
 #endif
