@@ -1,13 +1,19 @@
 //
 //
-// C++ Implementation: $MODULE$
-//
-// Description: 
+// Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>, (C) 2003
+// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2003 Liviu Lalescu <http://lalescu.ro/liviu/>
 //
-// Copyright: See COPYING file that comes with this distribution
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 //
 //
 
@@ -17,10 +23,7 @@
 #include "addroomform.h"
 #include "modifyroomform.h"
 
-#include <q3listbox.h>
-#include <qinputdialog.h>
-
-#include <QDesktopWidget>
+#include <QInputDialog>
 
 #include <QMessageBox>
 
@@ -90,7 +93,13 @@ void RoomsForm::addRoom()
 	
 	filterChanged();
 	
-	roomsListBox->setCurrentItem(ind);
+	//roomsListBox->setCurrentItem(ind);
+	Q_UNUSED(ind);
+	int i=roomsListBox->count()-1;
+	if(i>=0){
+		roomsListBox->setCurrentItem(i);
+		roomChanged(i);
+	}
 }
 
 void RoomsForm::removeRoom()
@@ -122,7 +131,8 @@ void RoomsForm::removeRoom()
 void RoomsForm::roomChanged(int index)
 {
 	if(index<0){
-		currentRoomTextEdit->setText(tr("Invalid room"));
+		//currentRoomTextEdit->setText(tr("Invalid room"));
+		currentRoomTextEdit->setText("");
 		return;
 	}
 
