@@ -29,27 +29,10 @@
 
 #include "lockunlock.h"
 
-#include <q3combobox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qapplication.h>
-#include <q3textedit.h>
-#include <qstring.h>
-#include <q3listbox.h>
-#include <qlabel.h>
-
-#include <QDesktopWidget>
+#include "matrix.h"
 
 #include <QMessageBox>
 
-/*#include <iostream>
-#include <fstream>
-using namespace std;*/
-
 #include <QTableWidget>
 #include <QTableWidgetItem>
 #include <QHeaderView>
@@ -60,6 +43,7 @@ using namespace std;*/
 #include <QSplitter>
 
 #include <QCoreApplication>
+#include <QApplication>
 
 #include <QString>
 #include <QStringList>
@@ -73,8 +57,10 @@ extern bool simulation_running;
 extern Solution best_solution;
 extern SpaceChromosome best_space_chromosome;
 
-extern double notAllowedRoomTimePercentages[MAX_ROOMS][MAX_HOURS_PER_WEEK];
-extern bool breakDayHour[MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
+//extern double notAllowedRoomTimePercentages[MAX_ROOMS][MAX_HOURS_PER_WEEK];
+extern Matrix2D<double> notAllowedRoomTimePercentages;
+//extern bool breakDayHour[MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
+extern Matrix2D<bool> breakDayHour;
 
 extern QSet <int> idsOfLockedTime;		//care about locked activities in view forms
 extern QSet <int> idsOfLockedSpace;		//care about locked activities in view forms
@@ -83,21 +69,6 @@ extern QSet <int> idsOfPermanentlyLockedSpace;	//care about locked activities in
 
 extern CommunicationSpinBox communicationSpinBox;	//small hint to sync the forms
 
-/////////////TODO
-/*
-#include <sys/time.h>
-
-#include <iostream>
-using namespace std;
-
-double get_time(){
-   struct timeval t;
-   gettimeofday(&t, NULL);
-   double d = t.tv_sec + (double) t.tv_usec/1000000;
-   return d;
-}*/
-/////////////
-
 TimetableViewRoomsForm::TimetableViewRoomsForm()
 {
     setupUi(this);
@@ -116,7 +87,7 @@ TimetableViewRoomsForm::TimetableViewRoomsForm()
 
     connect(closePushButton, SIGNAL(clicked()), this /*TimetableViewRoomsForm_template*/, SLOT(close()));
     connect(roomsListBox, SIGNAL(highlighted(QString)), this /*TimetableViewRoomsForm_template*/, SLOT(roomChanged(QString)));
-    connect(roomsTimetableTable, SIGNAL(itemClicked(QTableWidgetItem*)), this /*TimetableViewRoomsForm_template*/, SLOT(detailActivity(QTableWidgetItem*)));
+    connect(roomsTimetableTable, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)));
     connect(lockTimeSpacePushButton, SIGNAL(clicked()), this /*TimetableViewRoomsForm_template*/, SLOT(lock()));
     connect(lockTimePushButton, SIGNAL(clicked()), this /*TimetableViewRoomsForm_template*/, SLOT(lockTime()));
     connect(lockSpacePushButton, SIGNAL(clicked()), this /*TimetableViewRoomsForm_template*/, SLOT(lockSpace()));
@@ -345,14 +316,10 @@ void TimetableViewRoomsForm::updateRoomsTimetableTable(){
 				//added by Volker Dirr (end)
 			}
 			else{
-				if((notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0 || breakDayHour[k][j])
-				 && PRINT_NOT_AVAILABLE_TIME_SLOTS)
+				if(notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0 && PRINT_NOT_AVAILABLE_TIME_SLOTS)
 					s+="-x-";
-				/*if(!breakDayHour[k][j] && notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0 && notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]<100.0){
-					s+="\n";
-					s+=QString::number(notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]);
-					s+="%";
-				}*/
+				else if(breakDayHour[k][j] && PRINT_BREAK_TIME_SLOTS)
+					s+="-X-";
 			}
 			roomsTimetableTable->item(j, k)->setText(s);
 		}
@@ -375,6 +342,13 @@ void TimetableViewRoomsForm::resizeEvent(QResizeEvent* event){
 	roomsTimetableTable->resizeRowsToContents();
 }
 
+void TimetableViewRoomsForm::currentItemChanged(QTableWidgetItem* current, QTableWidgetItem* previous)
+{
+	Q_UNUSED(previous);
+	
+	detailActivity(current);
+}
+
 void TimetableViewRoomsForm::detailActivity(QTableWidgetItem* item){
 	if(item==NULL){
 		//detailsTextEdit->setText(tr("Invalid selected cell"));
